<?php

namespace FiloBlu\ExtAmastyGeoipRedirect\Model;

use FiloBlu\ExtAmastyGeoipRedirect\Model\ResourceModel\Continent\CollectionFactory;
use Magento\Framework\Data\Collection\AbstractDb;
use Magento\Framework\Model\AbstractModel;
use Magento\Framework\Model\Context;
use Magento\Framework\Model\ResourceModel\AbstractResource;
use Magento\Framework\Registry;

/**
 *
 */
class Continent extends AbstractModel
{

    protected $_continentCollectionFactory;

    /**
     * @param \FiloBlu\ExtAmastyGeoipRedirect\Model\ResourceModel\Continent\CollectionFactory $continentCollectionFactory
     * @param \Magento\Framework\Model\Context $context
     * @param \Magento\Framework\Registry $registry
     * @param \Magento\Framework\Model\ResourceModel\AbstractResource|null $resource
     * @param \Magento\Framework\Data\Collection\AbstractDb|null $resourceCollection
     * @param array $data
     */
    public function __construct(
        CollectionFactory $continentCollectionFactory,
        Context $context,
        Registry $registry,
        AbstractResource $resource = null,
        AbstractDb $resourceCollection = null,
        array $data = []
    ) {
        $this->_continentCollectionFactory = $continentCollectionFactory;
        parent::__construct($context, $registry, $resource, $resourceCollection, $data);
    }

    /**
     * @return \FiloBlu\ExtAmastyGeoipRedirect\Model\ResourceModel\Continent\Collection
     */
    public function getAvailableContinent()
    {
        $collection = $this->_continentCollectionFactory->create();
        $collection->addFieldToSelect(['continent_id', 'continent']);
        $collection->setOrder('position', 'ASC');

        return $collection;
    }

    /**
     * @param $continentId
     * @return \Magento\Framework\DataObject
     */
    public function getContinentById($continentId)
    {
        $collection = $this->_continentCollectionFactory->create();
        $collection->addFieldToSelect(['continent', 'position']);
        $collection->addFieldToFilter('continent_id', ['eq' => $continentId]);

        return $collection->getFirstItem();
    }

    /**
     * Initialize resource model
     *
     * @return void
     */
    protected function _construct()
    {
        $this->_init(ResourceModel\Continent::class);
    }

}
